@@ -14,7 +14,7 @@ standard_library.install_aliases()
 from .latex_object import LatexObject
 from .containers import Container, Environment, ContainerCommand
 from .command import CommandBase, Command, UnsafeCommand, Options, \
-    SpecialOptions, Arguments
+    SpecialOptions, Arguments, SpecialArguments
 from .float import Float
 
 # Old names of the base classes for backwards compatibility
