@@ -18,7 +18,7 @@ import sys
 import subprocess
 import errno
 from .base_classes import Environment, Command, Container, LatexObject, \
-    UnsafeCommand
+    UnsafeCommand, SpecialArguments
 from .package import Package
 from .errors import CompilerError
 from .utils import dumps_list, rm_temp_dir, NoEscape
@@ -132,7 +132,14 @@ class Document(Environment):
             packages.append(Package(u'microtype'))
 
         if geometry_options is not None:
-            packages.append(Package(u'geometry', options=geometry_options))
+            packages.append(Package(u'geometry'))
+            # Make sure we don't add this options command for an empty list,
+            # because that breaks.
+            if geometry_options:
+                packages.append(Command(
+                    u'geometry',
+                    arguments=SpecialArguments(geometry_options),
+                ))
 
         super(Document, self).__init__(data=data)
 
